@@ -42,7 +42,8 @@ Default CyREST API URL
 
 class Py4CytoscapeWrapper(object):
     """
-    Wrapper for py4cytoscape calls
+    Wrapper for `py4cytoscape <https://py4cytoscape.readthedocs.io/en/latest>`_
+    library
     """
 
     def __init__(self):
@@ -53,20 +54,36 @@ class Py4CytoscapeWrapper(object):
 
     def is_py4cytoscape_loaded(self):
         """
+        Checks if ``import py4cytoscape`` was successful
 
-        :return:
+        :return: True if py4cytoscape is loaded False otherwise
+        :rtype: bool
         """
         return self._py4loaded
 
     def cytoscape_ping(self, base_url=DEFAULT_CYREST_API):
         """
+        Calls :py:func:`py4cytoscape.cytoscape_system.cytoscape_ping`
 
-        :return:
+        :param base_url:
+        :type base_url: str
+        :return: See return value of
+                 :py:func:`py4cytoscape.cytoscape_system.cytoscape_ping`
         """
         return py4.cytoscape_ping(base_url=base_url)
 
     def delete_network(self, network=None,
                        base_url=DEFAULT_CYREST_API):
+        """
+        Calls :py:func:`py4cytoscape.networks.delete_network`
+
+        :param network:
+        :type network: SUID or str or None
+        :param base_url:
+        :type base_url: str
+        :return: See return value of
+                 :py:func:`py4cytoscape.networks.delete_network`
+        """
         return py4.delete_network(network=network,
                                   base_url=base_url)
 
@@ -74,25 +91,29 @@ class Py4CytoscapeWrapper(object):
                        type=None, network=None,
                        base_url=DEFAULT_CYREST_API):
         """
+        Calls :py:func:`py4cytoscape.networks.export_network`
 
         :param filename:
         :param type:
         :param network:
         :param base_url:
-        :return:
+        :return: See return value of
+                 :py:func:`py4cytoscape.networks.export_network`
         """
         return py4.export_network(filename=filename,
-                       type=type, network=network,
-                       base_url=base_url)
+                                  type=type, network=network,
+                                  base_url=base_url)
 
     def layout_network(self, layout_name=None,
                        network=None, base_url=DEFAULT_CYREST_API):
         """
+        Calls :py:func:`py4cytoscape.networks.layout_network`
 
         :param layout_name:
         :param network:
         :param base_url:
-        :return:
+        :return: See return value of
+                 :py:func:`py4cytoscape.networks.layout_network`
         """
         return py4.layout_network(layout_name=layout_name,
                                   network=network, base_url=base_url)
@@ -100,19 +121,23 @@ class Py4CytoscapeWrapper(object):
     def import_network_from_file(self, input_cx_file,
                                  base_url=DEFAULT_CYREST_API):
         """
+        Calls :py:func:`py4cytoscape.networks.import_network_from_file`
 
         :param input_cx_file:
         :param base_url:
-        :return:
+        :return: See return value of
+                 :py:func:`py4cytoscape.networks.import_network_from_file`
         """
         return py4.import_network_from_file(input_cx_file,
                                             base_url=base_url)
 
     def get_layout_name_mapping(self, base_url=DEFAULT_CYREST_API):
         """
+        Calls :py:func:`py4cytoscape.layouts.get_layout_name_mapping`
 
         :param base_url:
-        :return:
+        :return: See return value of
+                 :py:func:`py4cytoscape.layouts.get_layout_name_mapping`
         """
         return py4.get_layout_name_mapping(base_url=base_url)
 
@@ -194,9 +219,13 @@ class CytoscapeLayoutCommand(object):
         if self._args.layout == CytoscapeLayoutCommand.LIST_LAYOUT or \
                 self._args.layout == CytoscapeLayoutCommand.LIST_LAYOUTS:
             sys.stdout.write(CytoscapeLayoutCommand.
-                             get_supported_layouts(self._args.cyresturl))
+                             get_supported_layouts(self._args.cyresturl,
+                                                   py4_wrapper=self._py4))
             return 0
 
+        if self._args.layout == '-':
+            self._args.layout = 'force-directed-cl'
+
         self._parse_config()
         client = self._get_client()
         self._tmpdir = tempfile.mkdtemp(prefix=self._args.tmpdir)
@@ -206,7 +235,13 @@ class CytoscapeLayoutCommand(object):
             self._ndexextra.download_network_from_ndex(client=client,
                                                        networkid=self._args.uuid,
                                                        destfile=input_cx_file)
-            net_dict = self.load_network_in_cytoscape(input_cx_file)
+            tmp_output = input_cx_file
+            if self._args.updatefullnetwork is False:
+                tmp_output = input_cx_file + '.tmp.cx'
+                self._ndexextra.add_node_id_as_node_attribute(cxfile=input_cx_file,
+                                                              outcxfile=tmp_output)
+
+            net_dict = self.load_network_in_cytoscape(tmp_output)
             if 'networks' not in net_dict:
                 logger.fatal('Error network view could not '
                              'be created, this could be cause '
@@ -226,7 +261,14 @@ class CytoscapeLayoutCommand(object):
 
             if os.path.isfile(res_cx_file) and \
                     os.path.getsize(res_cx_file) > 0:
-                self.update_network_on_ndex(client=client, cxfile=res_cx_file)
+                if self._args.updatefullnetwork is True:
+                    self.update_network_on_ndex(client=client,
+                                                cxfile=res_cx_file)
+                else:
+                    u_cx_file = self.\
+                        extract_layout_aspect_from_cx(input_cx_file=res_cx_file)
+                    self.update_layout_aspect_on_ndex(client=client,
+                                                      cxfile=u_cx_file)
 
             return 0
         finally:
@@ -234,20 +276,6 @@ class CytoscapeLayoutCommand(object):
             self.delete_network(network_suid=net_suid)
             shutil.rmtree(self._tmpdir)
 
-    def get_node_id_map(self, input_cx=None,
-                        updated_cx=None):
-        """
-        Given an input CX file 'input_cx' and
-        a Cytoscape updated CX file. Generate
-        a dict with key set to id of node in 'updated_cx'
-        set to id of node in 'input_cx'
-        The lookup is done by examining the 'name' field if those
-        values are unique otherwise
-        :param input_cx:
-        :param updated_cx:
-        :return:
-        """
-
     def delete_network(self, network_suid=None):
         """
         Deletes network from Cytoscape
@@ -280,15 +308,11 @@ class CytoscapeLayoutCommand(object):
         with open(cxfile, 'r') as f:
             jdata = json.load(f)
 
-        net = NiceCXNetwork()
-        net.set_opaque_aspect('cartesianLayout', jdata)
-
-        theurl = '/network/' + self._args.uuid + '/aspects'
-        logger.info(theurl)
-        logger.info(net.to_cx())
-        res = client.put(theurl,
-                         put_json=json.dumps(net.to_cx()))
-        logger.info('Result from put: ' + str(res))
+        res = self._ndexextra.update_network_aspect_on_ndex(client=client,
+                                                            networkid=self._args.uuid,
+                                                            aspect_name='cartesianLayout',
+                                                            aspect_data=jdata)
+        logger.info('Result from aspect update: ' + str(res))
 
         return
 
@@ -363,7 +387,7 @@ class CytoscapeLayoutCommand(object):
         file_size = os.path.getsize(input_cx_file)
 
         logger.info('Importing network from file: ' + input_cx_file +
-                    ' (' + str(file_size) +' bytes) into Cytoscape')
+                    ' (' + str(file_size) + ' bytes) into Cytoscape')
         return self._py4.import_network_from_file(input_cx_file,
                                                   base_url=self._args.cyresturl)
 
@@ -378,23 +402,13 @@ class CytoscapeLayoutCommand(object):
                  or `None` if that aspect is NOT found
         :rtype: str
         """
+        res = self._ndexextra.extract_layout_aspect_from_cx(input_cx_file=input_cx_file)
         output_cx_file = os.path.join(self._tmpdir, 'cartlayout.json')
-        with open(output_cx_file, 'w') as outfp:
-            with open(input_cx_file, 'rb') as f:
-                for object in ijson.items(f, 'item.cartesianLayout'):
-                    # an inefficient fix to ijson setting the node
-                    # coordinates to type Decimal which breaks json.dump
-                    for node in object:
-                        # need to remap node ids
-                        if 'x' in node:
-                            node['x'] = float(node['x'])
-                        if 'y' in node:
-                            node['y'] = float(node['y'])
-                        if 'z' in node:
-                            node['z'] = float(node['z'])
-                    json.dump(object, outfp)
-
-        return output_cx_file
+        if res is not None:
+            with open(output_cx_file, 'w') as outfp:
+                json.dump(res, outfp)
+            return output_cx_file
+        return None
 
     @staticmethod
     def get_cytoscape_check_message(py4_wrapper=Py4CytoscapeWrapper()):
@@ -467,8 +481,17 @@ The network can be specified by NDEx UUID via --uuid flag.
 
 {cytocheck}
 
-Example:
+NOTE: if '-' is set as layout then force-directed-cl will be used.
 
+Examples:
+
+# to get list of Cytoscape layouts
+ndexmisctools.py cytoscapelayout listlayout - - - --uuid foo
+
+# to run with default force-directed-cl Cytoscape layout
+ndexmisctools.py cytoscapelayout - - - - --uuid XXXX-XXX
+
+# to run with perforce Cytoscape layout
 ndexmisctools.py cytoscapelayout perforce - - - --uuid XXXX-XXX
 
 WARNING: THIS IS AN UNTESTED ALPHA IMPLEMENTATION AND MAY CONTAIN
@@ -487,7 +510,9 @@ WARNING: THIS IS AN UNTESTED ALPHA IMPLEMENTATION AND MAY CONTAIN
                             help='Name of layout to run. Set layout name '
                                  'to ' +
                                  CytoscapeLayoutCommand.LIST_LAYOUT +
-                                 ' to see all options')
+                                 ' to see all options. If "-" is passed in, '
+                                 'layout of force-directed-cl '
+                                 'will be used')
         parser.add_argument('username', help='NDEx username, if set to - '
                                              'then value from config will '
                                              'be used')
@@ -519,5 +544,7 @@ WARNING: THIS IS AN UNTESTED ALPHA IMPLEMENTATION AND MAY CONTAIN
                             default=DEFAULT_CYREST_API,
                             help='URL of CyREST API. Default value'
                                  'is default for locally running Cytoscape')
-
+        parser.add_argument('--updatefullnetwork', action='store_true',
+                            help='If set, Update entire network on NDEx instead of '
+                                 'just the cartesianLayout aspect')
         return parser
\ No newline at end of file
